jacinle.cli.device
==================

.. automodule:: jacinle.cli.device

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DeviceNameFormat
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      canonlize_device_name
      parse_and_set_devices
      parse_devices
      set_cuda_visible_devices
   
   

   
   
   








.. rubric:: Class DeviceNameFormat
.. autoclass:: DeviceNameFormat
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: canonlize_device_name

.. autofunction:: parse_and_set_devices

.. autofunction:: parse_devices

.. autofunction:: set_cuda_visible_devices


